# WARNING: This package is synced with FC
%global major 0
%global apiversion 0.14
%define libname %mklibname ixion %apiversion %major
%define devname %mklibname -d ixion

Name: libixion
Version: 0.14.1
Release: %mkrel 1
Summary: A general purpose formula parser & interpreter library

Group: System/Libraries
License: MPLv2.0
URL: https://gitlab.com/ixion/ixion
Source0: http://kohei.us/files/ixion/src/%{name}-%{version}.tar.xz

BuildRequires: boost-devel
BuildRequires: help2man
BuildRequires: pkgconfig(mdds-1.4)
BuildRequires: pkgconfig(python3)
ExcludeArch:   armv5tl

%description
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

The goal of this project is to create a library for calculating the results of
formula expressions stored in multiple named targets, or “cells”. The cells can
be referenced from each other, and the library takes care of resolving their
dependencies automatically upon calculation. The caller can run the calculation
routine either in a single-threaded mode, or a multi-threaded mode. The library
also supports re-calculations where the contents of one or more cells have been
modified since the last calculation, and a partial calculation of only the
affected cells need to be calculated.

Supported features:
- Each calculation session is defined in a plain text file, which is parsed and
  interpreted by the Ixion parser.
- Fully threaded calculation.
- Name resolution using A1-style references.
- Support 2D cell references and named expressions.
- Support range references.
- Dependency tracking during both full calculation and partial re-calculation.
- Inline strings.
- Volatile functions. The framework for volatile functions is implemented. We
  just need to implement more functions.

%package -n %libname
Summary: A general purpose formula parser & interpreter library
Group: System/Libraries
Obsoletes: %{_lib}ixion0 < 0.7.0-3

%description -n %libname
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

The goal of this project is to create a library for calculating the results of
formula expressions stored in multiple named targets, or “cells”. The cells can
be referenced from each other, and the library takes care of resolving their
dependencies automatically upon calculation. The caller can run the calculation
routine either in a single-threaded mode, or a multi-threaded mode. The library
also supports re-calculations where the contents of one or more cells have been
modified since the last calculation, and a partial calculation of only the
affected cells need to be calculated.

Supported features:
- Each calculation session is defined in a plain text file, which is parsed and
  interpreted by the Ixion parser.
- Fully threaded calculation.
- Name resolution using A1-style references.
- Support 2D cell references and named expressions.
- Support range references.
- Dependency tracking during both full calculation and partial re-calculation.
- Inline strings.
- Volatile functions. The framework for volatile functions is implemented. We
  just need to implement more functions.

%package -n %devname
Summary: Development files for %{name}
Group: Development/C
Requires: %{libname} = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package tools
Summary: Testing tools for libixion
Group: Office/Utilities
Requires: %{libname} = %{version}-%{release}

%description tools
Testing tools for %{name}.

%package -n python3-%name
Summary: Python 3 bindings for libixion
Group: System/Libraries
Obsoletes: %{name}-python
Suggests: %{name}-doc = %{version}-%{release}

%description -n python3-%name
Python 3 bindings for %{name}.

%package doc
Summary: API documentation for %{name}
Group:  Documentation
BuildArch: noarch

%description doc
API documentation for %{name}.

%prep
%autosetup -p1

%build
%configure2_5x --disable-silent-rules --disable-static --disable-werror

sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make

%install
%makeinstall_std
rm -f %{buildroot}%{_libdir}/*.la %{buildroot}%{python3_sitearch}/*.la

# create and install man pages
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
help2man -S '%{name} %{version}' -N -n 'formula tokenizer' -o ixion-formula-tokenizer.1 ./src/ixion-formula-tokenizer
help2man -S '%{name} %{version}' -N -n 'parser' -o ixion-parser.1 ./src/ixion-parser
help2man -S '%{name} %{version}' -N -n 'sorter' -o ixion-sorter.1 ./src/ixion-sorter
install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -m 0644 ixion-*.1 %{buildroot}/%{_mandir}/man1

# generate docs
# make doc

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
%make check

%files -n %libname
%doc AUTHORS
%license LICENSE
%{_libdir}/%{name}-%{apiversion}.so.%{major}
%{_libdir}/%{name}-%{apiversion}.so.%{major}.*

%files -n %devname
%{_includedir}/%{name}-%{apiversion}
%{_libdir}/%{name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{name}-%{apiversion}.pc

%files tools
%{_bindir}/ixion-formula-tokenizer
%{_bindir}/ixion-parser
%{_bindir}/ixion-sorter
%{_mandir}/man1/ixion-formula-tokenizer.1*
%{_mandir}/man1/ixion-parser.1*
%{_mandir}/man1/ixion-sorter.1*

%files -n python3-%name
%{python3_sitearch}/ixion.so

%files doc
%license LICENSE
%doc doc/python



%changelog
* Sat Feb 09 2019 neoclust <neoclust> 0.14.1-1.mga6
+ Revision: 1364443
- New version

* Sun Feb 26 2017 tv <tv> 0.12.2-1.mga6
+ Revision: 1087984
- new release

* Fri Sep 23 2016 tv <tv> 0.12.0-3.mga6
+ Revision: 1055572
- just exclude on armv5tl

* Fri Sep 23 2016 tv <tv> 0.12.0-2.mga6
+ Revision: 1055571
- use --disable-threads on armv5 (debian#727621: armel: std::future appears to be broken)

* Mon Sep 19 2016 tv <tv> 0.12.0-1.mga6
+ Revision: 1054523
- use %%license
- add doc subpkg
- use %%autosetup
- fix tools description
- new release

* Wed Mar 02 2016 tv <tv> 0.11.0-1.mga6
+ Revision: 983097
- adjust rm to py2 -> py3 switch
- new release
- switch to python3
- fix python subpkg summary

* Fri Dec 25 2015 tv <tv> 0.9.1-5.mga6
+ Revision: 914721
- rebuild for new boost 1.60

* Fri Dec 25 2015 tv <tv> 0.9.1-4.mga6
+ Revision: 914682
- rebuild for boost 1.60
- use BR style for python-devel

* Fri Sep 25 2015 tv <tv> 0.9.1-3.mga6
+ Revision: 883537
- rebuild for new boost

* Wed Aug 26 2015 tv <tv> 0.9.1-2.mga6
+ Revision: 869853
- rebuild with gcc5

* Fri Jul 31 2015 neoclust <neoclust> 0.9.1-1.mga6
+ Revision: 859834
- New version 0.9.1
- Rebuild against new boost

* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-5.mga5
+ Revision: 748054
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-4.mga5
+ Revision: 681544
- Mageia 5 Mass Rebuild

* Fri Aug 08 2014 wally <wally> 0.7.0-3.mga5
+ Revision: 661131
- fix lib pkg name and summary

* Thu Jul 31 2014 tv <tv> 0.7.0-2.mga5
+ Revision: 658682
- fix package names
- rebuild for having a fixed package

* Thu Jul 31 2014 tv <tv> 0.7.0-1.mga5
+ Revision: 658603
- imported package libixion


* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 22 2014 David Tardon <dtardon@redhat.com> - 0.7.0-1
- initial import
